AsyncInput

Struct AsyncInput 

pub struct AsyncInput { /* private fields */ }
Async wrapper for agb input operations

Implementations

Source

impl AsyncInput

pub async fn wait_for_button_press(&mut self, button: Button) -> ButtonEvent

Wait for a specific button to be pressed

pub async fn wait_for_any_button_press(&mut self) -> (Button, ButtonEvent)

Wait for any button to be pressed or released

pub async fn wait_for_button_press_polling( &mut self, button: Button, ) -> ButtonEvent

Wait for a specific button to be pressed using agb’s ButtonController

pub async fn wait_for_any_button_press_polling( &mut self, ) -> (Button, ButtonEvent)

Wait for any button to be pressed using agb’s ButtonController

pub fn update(&mut self)

Get current button state (non-blocking)

pub fn is_pressed(&self, button: Button) -> bool

Check if a button is currently pressed

pub fn is_pressed_polling(&self, button: Button) -> bool

Check if a button is currently pressed using agb’s ButtonController

pub fn is_just_pressed_polling(&self, button: Button) -> bool

Check if a button was just pressed this frame using agb’s ButtonController

pub fn x_tri(&self) -> Tri

Get the tri-state for directional inputs (non-blocking)

pub fn y_tri(&self) -> Tri

Get the tri-state for directional inputs (non-blocking)