pub struct Executor { /* private fields */ }
Embassy executor with automatic Halt mode when idle
Create a new executor for GBA
Run the executor (never returns)
Polls tasks continuously, entering Halt mode when idle to save power.
TypeId
self
Returns the argument unchanged.
Calls U::from(self).
U::from(self)
That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.
[From]<T> for U