pub struct FrameEvents {
pub frame_count: u32,
/* private fields */
}Expand description
Frame events returned by GbaPeripherals::wait_frame()
Provides information about what happened during the frame.
What’s Included
- Button presses: Buttons that transitioned from released to pressed
- Button releases: Buttons that transitioned from pressed to released
- Frame counter: Auto-incrementing counter for animations and timing
Fields
frame_count: u32Frame counter (wraps at u32::MAX)
Implementations
Sourceimpl FrameEvents
impl FrameEvents
Sourcepub fn is_pressed(&self, button: Button) -> bool
pub fn is_pressed(&self, button: Button) -> bool
Check if a specific button was just pressed this frame
Sourcepub fn is_released(&self, button: Button) -> bool
pub fn is_released(&self, button: Button) -> bool
Check if a specific button was just released this frame
Sourcepub fn any_pressed(&self) -> bool
pub fn any_pressed(&self) -> bool
Check if any button was pressed this frame
Sourcepub fn any_released(&self) -> bool
pub fn any_released(&self) -> bool
Check if any button was released this frame
Get all buttons that were pressed this frame as a bitmask
Get all buttons that were released this frame as a bitmask