pub struct AsyncInput { /* private fields */ }Expand description
Async wrapper for agb input operations
Implementations
Sourceimpl AsyncInput
impl AsyncInput
Wait for a specific button to be pressed
Wait for any button to be pressed or released
Wait for a specific button to be pressed using agb’s ButtonController
Wait for any button to be pressed using agb’s ButtonController
Sourcepub fn is_pressed(&self, button: Button) -> bool
pub fn is_pressed(&self, button: Button) -> bool
Check if a button is currently pressed
Sourcepub fn is_pressed_polling(&self, button: Button) -> bool
pub fn is_pressed_polling(&self, button: Button) -> bool
Check if a button is currently pressed using agb’s ButtonController
Sourcepub fn is_just_pressed_polling(&self, button: Button) -> bool
pub fn is_just_pressed_polling(&self, button: Button) -> bool
Check if a button was just pressed this frame using agb’s ButtonController